---
title: <span class="badge object-type-scalar"></span> DatetimeISO
---
# <span class="badge object-type-scalar"></span> DatetimeISO

Date & time: Datetime ISO

## Definition

```python
# Date & time: Datetime ISO
DatetimeISO: typing.Literal["dateTimeAsIso"] = "dateTimeAsIso"
```
